@@ -33,7 +33,8 @@ def get_data(save_dataset_fd,documents):
 
     train_list_of_graphs, test_list_of_graphs = [],[]
 
-    trainingProportion = (len(all_files) / 100) * 80
+    trainingProportion = round(((len(all_files) / 100) * 80))
+
     training, testing = all_files[:trainingProportion], all_files[trainingProportion:]
 
     for file in all_files:
