@@ -20,12 +20,8 @@ from tensorflow.python.keras.callbacks import EarlyStopping
 
 
 class GraphManager :
-    def __init__(self, documents, tagsPath,save_dataset_fd):
-        tags = []
-        with open(tagsPath, newline='') as inputfile:
-            for row in csv.reader(inputfile):
-                tags.append(row[0])
-        self.nodes, self.edges, self.tags = get_data(documents=documents,save_dataset_fd=save_dataset_fd)
+    def __init__(self, documents,save_dataset_fd):
+        get_data(documents=documents,save_dataset_fd=save_dataset_fd)
 
     def TrainModel(self):
         nodes = self.nodes
